import React, { useState } from 'react';
import {
    View,
    Text,
    Image,
    TextInput,
    DeviceEventEmitter,
    TouchableHighlight,
    TouchableNativeFeedback,
    Platform,
    Alert
} from 'react-native';
import { BMCUI, ImagePicker } from './ui.js'

async function choosePic(openCamera, selectPic) {
    try {
        const {
            path,
            paths
        } = await ImagePicker.choosePic(openCamera, selectPic);

        console.log("path:" + path + " / paths:" + paths);
        BMCUI.show("path:" + path + " / paths:" + paths);
    } catch (e) {
        console.error(e);
    }
}

function imageClick() {
    if (Platform.OS == 'android') {
        choosePic(ImagePicker.OPEN_CAMERA, ImagePicker.SELECTED_IMAGES);
    } else {
        Alert.alert("ios undefine");
    }
}

function Cat(props) {
    return (
        <View style={{ flexDirection: "row" }}>
            <TouchableNativeFeedback onPress={imageClick}>
                <Image
                    source={{
                        uri: 'https://reactnative.dev/docs/assets/p_cat2.png',
                    }}
                    style={{ width: 120, height: 120 }}
                />
            </TouchableNativeFeedback>
            <Text style={{ padding: 10, fontSize: 42, flexWrap: "wrap" }}>
                {props.textTrans.split(' ').map((word) => word && '🍕').join(' ')}
            </Text>
        </View>
    );
}
export default class CustomerView extends React.Component {
    constructor(props) {
        super(props);
        console.log("CustomerView constructor");
        /**
         * useState does two things:
         * 1:it creates a “state variable” with an initial value—in this case the state variable is textTrans and its initial value is ''
         * 2:it creates a function to set that state variable’s value—setInputText
         * It doesn’t matter what names you use. But it can be handy to think of the pattern as [<getter>, <setter>] = useState(<initialValue>).
         * 
         * 虽然textTrans使用了常量关键字const，但它看起来还是可以修改！
         * What is happening is when a state-setting function like setInputText is called, its component will re-render. 
         * In this case the Cat function will run again—and this time, useState will give us the next value of textTrans. 
         */
        //const [textTrans, setInputText] = useState('');
        this.state = {
            textTrans: ''
        };
    }

    componentDidMount() {
        console.log("CustomerView componentDidMount");
        this.eventListener = DeviceEventEmitter.addListener('msg', (a) => {
            // alert('收到通知：' + a);
            console.log("收到通知：" + a);
            if (a && a.test) {
                tip = a.test
            } else {
                tip = a
            }
            BMCUI.showConfirmDialogWithCancelable(false, "收到新消息：" + tip, "确定", (result) => {
                console.log("你点击了取确定按钮，结果为：" + result);
            });
        });
    }

    shouldComponentUpdate(nextProps, nextState, nextContext) {
        console.log("CustomerView shouldComponentUpdate nextProps:" + nextProps);
        console.log("CustomerView shouldComponentUpdate nextState.textTrans:" + nextState.textTrans + " / currState.textTrans:" + this.state.textTrans);

        return (nextState.textTrans || this.state.textTrans)
            && (nextState.textTrans.split(' ').length != this.state.textTrans.split(' ').length
                || (nextState.textTrans.length == 1 && this.state.textTrans.length == 0))
    }

    componentWillUnmount() {
        console.log("CustomerView componentWillUnmount");
        this.eventListener.remove(); // Removes the listener
    }

    componentDidCatch(error, errorInfo) {
        console.log("CustomerView componentDidCatch");
    }

    render() {
        return (
            <>
                <Cat textTrans={this.state.textTrans} />
                <TextInput
                    style={{
                        height: 40,
                        margin: 10,
                        borderColor: 'gray',
                        borderWidth: 1
                    }}
                    placeholder="Type here to translate!"
                    onChangeText={text => this.setState({ textTrans: text })}
                    defaultValue={this.state.textTrans}
                />
            </>
        );
    }
}